@@ -13,6 +13,8 @@
 ## along with Lino; if not, see <http://www.gnu.org/licenses/>.
 
 """
+The :xfile:`models.py` module for the :mod:`lino_welfare` app.
+
 Contains PCSW-specific models and tables that have not yet been 
 moved into a separate module because they are really very PCSW specific.
 
@@ -177,29 +179,6 @@ if False:
 
         
 
-def customize_notes():
-    """
-    Application-specific changes to :mod:`lino.modlib.notes`.
-    """
-    #~ from lino.modlib.notes.models import Note, Notes
-    notes = dd.resolve_app('notes')
-
-    dd.inject_field(notes.Note,'company',
-        models.ForeignKey('contacts.Company',
-            blank=True,null=True,
-            help_text="""\
-    An optional third-party Organization that is related to this Note.
-    The note will then be visible in that company's history panel.
-    """
-        ))
-        
-    def get_person(self):
-        return self.project
-    notes.Note.person = property(get_person)
-        
-      
-
-
 @dd.receiver(dd.auto_create)
 def on_auto_create(sender,**kw):
     #~ raise Warning("auto_create is not permitted here")
@@ -350,19 +329,21 @@ def site_setup(site):
     activity bank_account1:12 bank_account2:12
     """)
     
-    
-    site.modules.system.SiteConfigs.set_detail_layout("""
-    site_company system_note_type default_build_method 
-    next_partner_id:20 job_office debts_bailiff_type master_budget
-    signer1 signer2
-    signer1_function signer2_function 
-    constants
-    # lino.ModelsBySite
-    """,constants="""
-    propgroup_skills propgroup_softskills propgroup_obstacles
-    residence_permit_upload_type work_permit_upload_type driving_licence_upload_type
-    client_calender client_guestrole team_guestrole
-    """)
+    site.modules.system.SiteConfigs.set_detail_layout(
+        "general constants",
+        general=dd.Panel("""
+        site_company next_partner_id:10 
+        job_office debts_bailiff_type master_budget
+        signer1 signer2
+        signer1_function signer2_function 
+        """,label=_("General")),constants=dd.Panel("""
+        system_note_type default_build_method 
+        propgroup_skills propgroup_softskills propgroup_obstacles
+        residence_permit_upload_type work_permit_upload_type driving_licence_upload_type
+        client_calendar prompt_calendar 
+        client_guestrole team_guestrole 
+        attestation_note_nature
+        """,label=_("Constants")))
     
     site.modules.properties.Properties.set_detail_layout("""
     id group type 
@@ -371,7 +352,7 @@ def site_setup(site):
     """)
     
     site.modules.countries.Cities.set_detail_layout("""
-    name country inscode 
+    name country inscode zip_code
     parent type id
     CitiesByCity
     contacts.PartnersByCity jobs.StudiesByCity
@@ -447,34 +428,6 @@ def site_setup(site):
     """,_("Coaching"),)
     
         
-    site.modules.notes.Notes.set_detail_layout(
-        left = """
-        date:10 event_type:25 type:25
-        subject 
-        project company
-        id user:10 language:8 build_time
-        body
-        """,
-        
-        right = """
-        uploads.UploadsByController
-        outbox.MailsByController
-        postings.PostingsByController
-        cal.TasksByController
-        """,
-        
-        main = """
-        left:60 right:30
-        """
-    )
-    
-    
-    site.modules.notes.Notes.set_insert_layout("""
-    event_type:25 type:25
-    subject 
-    project company
-    """,window_size=(50,'auto'))
-    
     #~ site.modules.outbox.Mails.set_detail_layout("""
     #~ subject project date 
     #~ user sent #build_time id owner
@@ -502,7 +455,7 @@ def set_merge_actions(sender,**kw):
 customize_siteconfig()
 #~ customize_countries()
 customize_contacts()        
-customize_notes()
+#~ customize_notes()
 customize_sqlite()
 customize_users()
 
@@ -512,38 +465,3 @@ customize_users()
   
 
 
-def setup_workflows(site):
-
-    #~ ClientStates.newcomer.add_transition(states='refused coached invalid former',user_groups='newcomers')
-    
-    def allow_state_newcomer(action,user,obj,state):
-        """
-        A Client with at least one Coaching cannot become newcomer.
-        """
-        #~ if obj.client_state == ClientStates.coached:
-        if obj.coachings_by_client.count() > 0:
-            return False
-        return True
-    
-    
-    pcsw.ClientStates.newcomer.add_transition(states='refused coached former',
-        user_groups='newcomers',allow=allow_state_newcomer)
-    pcsw.ClientStates.refused.add_transition(pcsw.RefuseClient)
-    #~ ClientStates.refused.add_transition(_("Refuse"),states='newcomer invalid',user_groups='newcomers',notify=True)
-    #~ ClientStates.coached.add_transition(_("Coached"),states='new',user_groups='newcomers')
-    pcsw.ClientStates.former.add_transition(_("Former"),
-        #~ states='coached invalid',
-        states='coached',
-        user_groups='newcomers')
-    #~ ClientStates.add_transition('new','refused',user_groups='newcomers')
-
-
-
-#~ def setup_main_menu(site,ui,profile,m): 
-def setup_reports_menu(site,ui,profile,m):
-    #~ m.add_action(site.modules.jobs.OldJobsOverview)
-    m.add_action(site.modules.pcsw.UsersWithClients)
-    m.add_action(site.modules.pcsw.ClientsTest)
-    #~ m  = m.add_menu("pcsw",pcsw.MODULE_LABEL)
-    #~ m.add_action(ActivityReport1) # old version
-        
