@@ -13,9 +13,9 @@
 ## along with Lino; if not, see <http://www.gnu.org/licenses/>.
 
 """
-ISIP (Individualized Social Integration 
-Projects, fr. "PIIS", german "VSE")
-are contracts between a PCSW and a Client.
+The :xfile:`models.py` module for the 
+:mod:`lino_welfare.modlib.isip` app
+(eee :ddref:`isip`)
 
 """
 
@@ -41,7 +41,8 @@ from lino import mixins
 #~ from lino.modlib.notes import models as notes
 notes = dd.resolve_app('notes')
 contacts = dd.resolve_app('contacts')
-pcsw = dd.resolve_app('pcsw')
+#~ pcsw = dd.resolve_app('pcsw')
+#~ integ = dd.resolve_app('integ')
 
 #~ from lino.modlib.links import models as links
 from lino.modlib.uploads import models as uploads
@@ -59,6 +60,7 @@ from lino.mixins.printable import DirectPrintAction
 
 from lino_welfare.modlib.system.models import Signers
 
+from lino_welfare.modlib.isip import App
 
 def rangefmt(r):
     return dd.dtos(r[0]) + '...' + dd.dtos(r[1])
@@ -155,14 +157,18 @@ class ExamPolicies(dd.Table):
     jobs.ContractsByPolicy    
     """
 
+
+from lino_welfare.modlib.jobs import App as JobsApp
+JOBS_MODULE_NAME = JobsApp.verbose_name
+    
 class ContractEnding(dd.Model):
     class Meta:
         verbose_name = _("Reason of termination")
         verbose_name_plural = _('Contract termination reasons')
         
     name = models.CharField(_("designation"),max_length=200)
-    use_in_isip = models.BooleanField(_("ISIP"),default=True)
-    use_in_jobs = models.BooleanField(pcsw.JOBS_MODULE_LABEL,default=True)
+    use_in_isip = models.BooleanField(App.verbose_name,default=True)
+    use_in_jobs = models.BooleanField(JOBS_MODULE_NAME,default=True)
     is_success = models.BooleanField(_("Success"),default=False)
     needs_date_ended = models.BooleanField(_("Require date ended"),default=False)
     
@@ -221,9 +227,9 @@ class ContractBase(
     cal.EventGenerator):
     """
     Abstract base class for 
-    :class:`lino_welfare.modlib.jobs.models.Contract`
+    :ddref:`jobs.Contract`
     and
-    :class:`lino_welfare.modlib.isip.models.Contract`
+    :ddref:`isip.Contract`.
     """
     
     manager_level_field = 'integ_level'
@@ -266,13 +272,6 @@ class ContractBase(
     hidden_columns = 'date_decided date_issued exam_policy user_asd ending date_ended signer1 signer2'
     
     
-    #~ def summary_row(self,ui,rr,**kw):
-    def summary_row(self,ar,**kw):
-        s = ar.href_to(self)
-        #~ s += " (" + ui.href_to(self.person) + ")"
-        #~ s += " (" + ui.href_to(self.person) + "/" + ui.href_to(self.provider) + ")"
-        return s
-        
             
     def __unicode__(self):
         #~ return u'%s # %s' % (self._meta.verbose_name,self.pk)
@@ -397,9 +396,9 @@ class ContractBase(
     def update_cal_from(self):
         return self.applies_from
         
-    def update_cal_calendar(self,i):
-        #~ return self.exam_policy.event_type
-        return self.exam_policy.calendar
+    def update_cal_calendar(self):
+        if self.exam_policy is not None:
+            return self.exam_policy.calendar
         
     def update_cal_until(self):
         return self.date_ended or self.applies_until
@@ -802,26 +801,20 @@ class ContractsByStudyType(Contracts):
 #~ customize_siteconfig()
 
 
+#~ from lino_welfare.modlib.integ import App
 
-
-def setup_main_menu(site,ui,profile,m): 
-    m  = m.add_menu("integ",pcsw.INTEG_MODULE_LABEL)
-    m.add_action(MyContracts)
-    
-def setup_master_menu(site,ui,profile,m): pass
-
-def setup_my_menu(site,ui,profile,m): pass
+#~ def setup_main_menu(site,ui,profile,m): 
+    #~ m  = m.add_menu("integ",App.verbose_name)
     #~ m.add_action(MyContracts)
-  
-def setup_config_menu(site,ui,profile,m): 
-    #~ m  = m.add_menu("isip",_("ISIPs"))
-    m  = m.add_menu("integ",pcsw.INTEG_MODULE_LABEL)
-    m.add_action(ContractTypes)
-    m.add_action(ContractEndings)
-    m.add_action(ExamPolicies)
-    m.add_action(StudyTypes)
-  
-def setup_explorer_menu(site,ui,profile,m):
-    m  = m.add_menu("integ",pcsw.INTEG_MODULE_LABEL)
-    m.add_action(Contracts)
-
+    
+#~ def setup_config_menu(site,ui,profile,m): 
+    #~ m  = m.add_menu("integ",App.verbose_name)
+    #~ m.add_action(ContractTypes)
+    #~ m.add_action(ContractEndings)
+    #~ m.add_action(ExamPolicies)
+    #~ m.add_action(StudyTypes)
+  #~ 
+#~ def setup_explorer_menu(site,ui,profile,m):
+    #~ m  = m.add_menu("integ",App.verbose_name)
+    #~ m.add_action(Contracts)
+#~ 
