@@ -50,10 +50,6 @@ from lino.utils import dblogger
 #~ from lino.utils import printable
 from lino import mixins
 
-uploads = dd.resolve_app('uploads')
-notes = dd.resolve_app('notes')
-contacts = dd.resolve_app('contacts')
-
 #~ from lino.modlib.contacts import models as contacts
 #~ from lino.modlib.notes import models as notes
 #~ from lino.modlib.links import models as links
@@ -72,56 +68,13 @@ from lino.mixins.printable import DirectPrintAction
 from lino.modlib.countries.models import CountryCity
 from lino.modlib.cal.utils import DurationUnits
 
-# not used here, but these modules are required in INSTALLED_APPS, 
-# and other code may import them using 
-# ``from lino_welfare.modlib.pcsw.models import Property``
-
-from lino.modlib.properties.models import Property
-#~ from lino.modlib.notes.models import NoteType
-from lino.modlib.countries.models import Country, City
-
+uploads = dd.resolve_app('uploads')
+notes = dd.resolve_app('notes')
 contacts = dd.resolve_app('contacts')
 isip = dd.resolve_app('isip')
 pcsw = dd.resolve_app('pcsw')
 
-
-#~ SCHEDULE_CHOICES = {
-    #~ 'de':[ 
-        #~ u"5-Tage-Woche",
-        #~ u"Montag, Mittwoch, Freitag",
-        #~ u"Individuell",
-        #~ ],
-    #~ 'fr':[ 
-        #~ u"5 jours/semaine",
-        #~ u"lundi,mercredi,vendredi",
-        #~ u"individuel",
-        #~ ],
-    #~ 'en':[
-        #~ u"5 days/week",
-        #~ u"Monday, Wednesday, Friday",
-        #~ u"Individual",
-        #~ ]
-#~ }
-
-#~ REGIME_CHOICES = {
-    #~ 'de':[ 
-        #~ u"20 Stunden/Woche",
-        #~ u"35 Stunden/Woche",
-        #~ u"38 Stunden/Woche",
-        #~ ],
-    #~ 'fr':[ 
-        #~ u"20 heures/semaine",
-        #~ u"35 heures/semaine",
-        #~ u"38 heures/semaine",
-        #~ ],
-    #~ 'en':[
-        #~ u"20 hours/week",
-        #~ u"35 hours/week",
-        #~ u"38 hours/week",
-        #~ u"38 hours/week",
-        #~ ]
-#~ }
-
+from lino_welfare.modlib.jobs import App
 
 class Schedule(dd.BabelNamed):
     """List of choices for `jobs.Contract.schedule` field."""
@@ -686,9 +639,10 @@ class Offer(SectorFunction):
     start_date = models.DateField(_("start date"),
         blank=True,null=True)
     
-    remark = models.TextField(
+    remark = dd.RichTextField(
         blank=True,
-        verbose_name=_("Remark"))
+        verbose_name=_("Remark"),
+        format='plain')
         
     def __unicode__(self):
         if self.name:
@@ -742,15 +696,16 @@ class Study(CountryCity):
         verbose_name=_("Study content"))
     #~ content = models.ForeignKey(StudyContent,blank=True,null=True,verbose_name=_("Study content"))
   
-    started = dd.MonthField(_("started"),blank=True,null=True)
-    stopped = dd.MonthField(_("stopped"),blank=True,null=True)
+    started = models.DateField(_("started"),blank=True,null=True)
+    stopped = models.DateField(_("stopped"),blank=True,null=True)
+    #~ started = dd.MonthField(_("started"),blank=True,null=True)
+    #~ stopped = dd.MonthField(_("stopped"),blank=True,null=True)
     #~ started = models.DateField(blank=True,null=True,verbose_name=_("started"))
     #~ stopped = models.DateField(blank=True,null=True,verbose_name=_("stopped"))
     #~ started = dd.MonthField(blank=True,null=True,verbose_name=_("started"))
     #~ stopped = dd.MonthField(blank=True,null=True,verbose_name=_("stopped"))
     success = models.BooleanField(verbose_name=_("Success"),default=False)
-    language = models.ForeignKey("countries.Language",
-        blank=True,null=True,verbose_name=_("Language"))
+    language = dd.ForeignKey("languages.Language",blank=True,null=True)
     #~ language = dd.LanguageField(blank=True,null=True,verbose_name=_("Language"))
     
     school = models.CharField(max_length=200,
@@ -796,6 +751,8 @@ class Experience(SectorFunction):
     class Meta:
         verbose_name = _("Job Experience")
         verbose_name_plural = _("Job Experiences")
+        get_latest_by =  'started'
+
     #~ person = models.ForeignKey(settings.SITE.person_model,verbose_name=_("Person"))
     person = models.ForeignKey('pcsw.Client')
     #~ company = models.ForeignKey("contacts.Company",verbose_name=_("Company"))
@@ -806,8 +763,10 @@ class Experience(SectorFunction):
         blank=True,null=True,
         verbose_name=_("Country"))
   
-    started = dd.MonthField(_("started"),blank=True,null=True)
-    stopped = dd.MonthField(_("stopped"),blank=True,null=True)
+    #~ started = dd.MonthField(_("started"),blank=True,null=True)
+    #~ stopped = dd.MonthField(_("stopped"),blank=True,null=True)
+    started = models.DateField(_("started"),blank=True,null=True)
+    stopped = models.DateField(_("stopped"),blank=True,null=True)
     
     remarks = models.TextField(blank=True,null=True,verbose_name=_("Remarks"))
     
@@ -985,6 +944,7 @@ class Candidature(SectorFunction):
     class Meta:
         verbose_name = _("Job Candidature")
         verbose_name_plural = _('Job Candidatures')
+        get_latest_by =  'date_submitted'
         
     #~ person = models.ForeignKey(settings.SITE.person_model)
     person = models.ForeignKey('pcsw.Client')
@@ -1100,7 +1060,8 @@ class SectorFunctionByOffer(dd.Table):
         if offer is None:
             return []
         kw = {}
-        qs = self.model.objects.order_by('date_submitted')
+        #~ qs = self.model.objects.order_by('date_submitted')
+        qs = self.model.objects.order_by(self.model._meta.get_latest_by)
         
         if offer.function:
             qs = qs.filter(function=offer.function)
@@ -1129,10 +1090,12 @@ class SectorFunctionByOffer(dd.Table):
 class CandidaturesByOffer(SectorFunctionByOffer):
     model = Candidature
     label = _("Candidates")
+    column_names = "date_submitted  person job state"
     
 class ExperiencesByOffer(SectorFunctionByOffer):
     model = Experience
-    label = _("Candidates")
+    label = _("Experiences")
+    column_names = "started stopped person company country"
     
 
 
@@ -1424,7 +1387,7 @@ class JobsOverviewByType(Jobs):
 
 class JobsOverview(dd.EmptyTable):
     """
-    New version of :ref:`welfare.jobs.JobsOverview`.
+    New version of `welfare.jobs.JobsOverview`.
     """
     required = dd.required(user_groups=['integ'])
     label = _("Contracts Situation") 
@@ -1442,7 +1405,7 @@ class JobsOverview(dd.EmptyTable):
     def create_instance(self,ar,**kw):
         kw.update(today = ar.param_values.today or datetime.date.today())
         if ar.param_values.job_type:
-            kw.update(jobtypes = ar.param_values.job_type)
+            kw.update(jobtypes = [ar.param_values.job_type])
         else:
             kw.update(jobtypes = JobType.objects.all())
         return super(JobsOverview,self).create_instance(ar,**kw)
@@ -1450,6 +1413,7 @@ class JobsOverview(dd.EmptyTable):
         
     @dd.virtualfield(dd.HtmlBox())
     def preview(cls,self,ar):
+        #~ logger.info("20130723 preview %s",self.jobtypes)
         html = []
         for jobtype in self.jobtypes:
             html.append(E.h2(unicode(jobtype)))
@@ -1457,6 +1421,8 @@ class JobsOverview(dd.EmptyTable):
                 master_instance=jobtype,
                 param_values=dict(date=self.today))
             html.append(sar.table2xhtml())
+        #~ logger.info("20130723 preview %s",html)
+        #~ return E.div(*html,class_='htmlText')
         return E.div(*html)
 
     @classmethod
@@ -1483,11 +1449,14 @@ if True: # dd.is_installed('contacts') and dd.is_installed('jobs'):
         """Whether this Company is also a Job Provider."""
         )
 
+#~ from lino_welfare.modlib.integ import App
 
-def setup_main_menu(site,ui,profile,m): 
+#~ INTEG_MODULE_LABEL = _(App.verbose_name)
+
+def unused_setup_main_menu(site,ui,profile,m): 
     #~ if user.profile.integ_level < UserLevels.user:
         #~ return
-    m  = m.add_menu("integ",pcsw.INTEG_MODULE_LABEL)
+    m  = m.add_menu("integ",INTEG_MODULE_LABEL)
     m.add_action(MyContracts)
     m.add_action(JobProviders)
     m.add_action(Jobs)
@@ -1499,10 +1468,10 @@ def setup_main_menu(site,ui,profile,m):
 #~ def setup_my_menu(site,ui,user,m): 
     #~ m.add_action(MyContracts)
   
-def setup_config_menu(site,ui,profile,m): 
+def unused_setup_config_menu(site,ui,profile,m): 
     #~ if user.profile.integ_level < UserLevels.manager:
         #~ return
-    m  = m.add_menu("integ",pcsw.INTEG_MODULE_LABEL)
+    m  = m.add_menu("integ",INTEG_MODULE_LABEL)
     #~ m  = m.add_menu("jobs",MODULE_LABEL)
     m.add_action(ContractTypes)
     m.add_action(JobTypes)
@@ -1513,10 +1482,10 @@ def setup_config_menu(site,ui,profile,m):
     
     
   
-def setup_explorer_menu(site,ui,profile,m):
+def unused_setup_explorer_menu(site,ui,profile,m):
     #~ if user.profile.integ_level < UserLevels.manager:
         #~ return
-    m  = m.add_menu("integ",pcsw.INTEG_MODULE_LABEL)
+    m  = m.add_menu("integ",INTEG_MODULE_LABEL)
     #~ m  = m.add_menu("jobs",MODULE_LABEL)
     m.add_action(Contracts)
     m.add_action(Candidatures)
