@@ -24,10 +24,10 @@ def objects():
     pcsw = dd.resolve_app('pcsw')
     
     #~ persongroup = Instantiator('pcsw.PersonGroup','name').build
-    yield pcsw.PersonGroup(ref_name='1',name=_("Bilan"))
-    yield pcsw.PersonGroup(ref_name='2',name=_("Formation"))
-    yield pcsw.PersonGroup(ref_name='4',name=_("Recherche"))
-    yield pcsw.PersonGroup(ref_name='4bis',name=_("Travail"))
+    yield pcsw.PersonGroup(ref_name='1',name=_("Evaluation")) # Auswertung / Bilan
+    yield pcsw.PersonGroup(ref_name='2',name=_("Formation")) # Formation / Ausbildung
+    yield pcsw.PersonGroup(ref_name='4',name=_("Search")) # Suche / Recherche
+    yield pcsw.PersonGroup(ref_name='4bis',name=_("Work")) # Arbeit / Travail
     yield pcsw.PersonGroup(ref_name='9',name=_("Standby"))
     #~ yield persongroup(u"Bilan",ref_name='1')
     #~ yield persongroup(u"Formation",ref_name='2')
@@ -35,12 +35,24 @@ def objects():
     #~ yield persongroup(u"Travail",ref_name='4bis')
     #~ yield persongroup(u"Standby",ref_name='9',active=False)
 
-    yield pcsw.CoachingEnding(**babelkw('name',de="Übergabe an Kollege",fr="Transfert vers collègue"))
-    yield pcsw.CoachingEnding(**babelkw('name',de="Einstellung des Anrechts auf SH",fr="Arret du droit à l'aide sociale"))
-    yield pcsw.CoachingEnding(**babelkw('name',de="Umzug in andere Gemeinde",fr="Déménagement vers autre commune"))
-    yield pcsw.CoachingEnding(**babelkw('name',de="Hat selber Arbeit gefunden",fr="A trouvé du travail"))
+    yield pcsw.CoachingEnding(**babelkw('name',
+        de="Übergabe an Kollege",
+        fr="Transfert vers collègue",
+        en="Transfer to colleague",))
+    yield pcsw.CoachingEnding(**babelkw('name',
+        de="Einstellung des Anrechts auf SH",
+        fr="Arret du droit à l'aide sociale",
+        en="End of right on social aid"))
+    yield pcsw.CoachingEnding(**babelkw('name',
+        de="Umzug in andere Gemeinde",
+        fr="Déménagement vers autre commune",
+        en="Moved to another town"))
+    yield pcsw.CoachingEnding(**babelkw('name',
+        de="Hat selber Arbeit gefunden",
+        fr="A trouvé du travail",
+        en="Found a job"))
     
-    yield pcsw.DispenseReason(**babelkw('name',de="Gesundheitlich",fr="Santé"))
-    yield pcsw.DispenseReason(**babelkw('name',de="Studium/Ausbildung",fr="Etude/Formation"))
-    yield pcsw.DispenseReason(**babelkw('name',de="Familiär",fr="Cause familiale"))
-    yield pcsw.DispenseReason(**babelkw('name',de="Sonstige",fr="Autre"))
+    yield pcsw.DispenseReason(**babelkw('name',de="Gesundheitlich",fr="Santé",en="Health"))
+    yield pcsw.DispenseReason(**babelkw('name',de="Studium/Ausbildung",fr="Etude/Formation",en="Studies"))
+    yield pcsw.DispenseReason(**babelkw('name',de="Familiär",fr="Cause familiale",en="Familiar"))
+    yield pcsw.DispenseReason(**babelkw('name',de="Sonstige",fr="Autre",en="Other"))
