@@ -13,7 +13,7 @@
 ## along with Lino; if not, see <http://www.gnu.org/licenses/>.
 
 """
-Default settings of a Lino/Welfare site.
+Default settings of a :ref:`welfare` site.
 
 """
 import os
@@ -41,6 +41,8 @@ class Site(Site,cbss.SiteMixin):
     
     demo_fixtures = 'std few_countries few_cities few_languages props cbss democfg demo demo2 demo_events'.split()
     
+    #~ catch_layout_exceptions = False # 20130804
+    
     #~ title = label # __name__
     #~ domain = "pcsw.saffre-rumma.net"
     #~ help_url = "http://packages.python.org/lino-welfare"
@@ -54,16 +56,16 @@ class Site(Site,cbss.SiteMixin):
     
     accounts_ref_length = 5
     
-    #~ languages = ('de', 'fr', 'nl', 'en')
-    #~ languages = "de fr nl en"
-    
-    #~ languages = ['en']
-    languages = 'de fr nl'
-    #~ languages = ['de','fr']
-    #~ languages = ['fr','de']
-    #~ languages = ['de']
+    languages = 'en fr de nl' # tested docs rely on this distribution
     
+    hidden_languages = 'nl'
     
+    def get_default_language(self):
+        """
+        Lino-Welfare was initially used and promoted in the German-speaking region.
+        """
+        return 'de' # self.languages[1].django_code
+        
     #~ index_view_action = "pcsw.Home"
     
     #~ remote_user_header = "REMOTE_USER"
@@ -75,7 +77,7 @@ class Site(Site,cbss.SiteMixin):
     
     def setup_choicelists(self):
         """
-        This defines default user profiles for :mod:`lino_welfare`.
+        This defines default user profiles for :ref:`welfare`.
         """
         from lino import dd
         from django.utils.translation import ugettext_lazy as _
@@ -85,12 +87,13 @@ class Site(Site,cbss.SiteMixin):
             name='anonymous', readonly=True,authenticated=False)
         add('100', _("Integration Agent"),          'U U U U _ _ _')
         add('110', _("Integration Agent (Manager)"),'U M M U _ _ _')
-        add('200', _("Newcomers consultant"),       'U U _ U U _ U')
+        add('200', _("Newcomers consultant"),       'U U _ U U _ _')
         add('210', _("Reception clerk"),            'U _ _ _ _ _ U')
         add('300', _("Debts consultant"),           'U U _ _ _ U _')
+        add('400', _("Social agent"),               'U _ _ U _ _ _')
         #~ add('400', _("Readonly Manager"),           'M M M M M M', readonly=True)
         #~ add('400', _("Readonly User"),              'U U U U U U', readonly=True)
-        add('500', _("CBSS only"),                  'U _ _ U _ _ _')
+        #~ add('500', _("CBSS only"),                  'U _ _ U _ _ _')
         add('900', _("Administrator"),              'A A A A A A A',name='admin')
         
         #~ for p in dd.UserProfiles.items():
@@ -106,12 +109,12 @@ class Site(Site,cbss.SiteMixin):
         tb.add_action('pcsw.Clients','detail')
         self.on_each_app('setup_quicklinks',ar,tb)
         
-        tb.add_action(self.modules.pcsw.IntegClients)
+        tb.add_action(self.modules.integ.Clients)
         tb.add_action(self.modules.isip.MyContracts)
         tb.add_action(self.modules.jobs.MyContracts)
         #~ tb.add_action(self.modules.pcsw.Home)
         
-        tb.add_action(self.modules.pcsw.Clients,'find_by_beid')
+        #~ tb.add_action('reception.Clients','find_by_beid')
         
     def setup_menu(self,ui,profile,main):
         from django.utils.translation import ugettext_lazy as _
@@ -132,32 +135,19 @@ class Site(Site,cbss.SiteMixin):
         m = main.add_menu("master",_("Master"))
         self.on_each_app('setup_master_menu',ui,profile,m)
         
-        #~ if user.profile.integ_level:
-            #~ m = main.get_item("contacts")
-            #~ m.add_action(self.modules.pcsw.MyPersonSearches)
-            
-            
-        if profile.level and not profile.readonly:
-          
-            m = main.add_menu("my",_("My menu"))
-            #~ m.add_action('projects.Projects')
-            #~ m.add_action(self.modules.notes.MyNotes)
-            
-            self.on_each_app('setup_my_menu',ui,profile,m)
-            #~ m.add_action(self.modules.lino.MyTextFieldTemplates)
-
-        
         self.on_each_app('setup_main_menu',ui,profile,main)
         
-        m = main.get_item("contacts")
-        m.clear()
-        m.add_action(self.modules.contacts.Persons)
-        m.add_action(self.modules.pcsw.Clients,label=string_concat(u' \u25b6 ',self.modules.pcsw.Clients.label))
-        #~ m.add_action(self.modules.pcsw.Clients,'find_by_beid')
-        m.add_action(self.modules.contacts.Companies)
-        m.add_action(self.modules.households.Households)
-        m.add_separator('-')
-        m.add_action(self.modules.contacts.Partners,label=_("Partners (all)"))
+        if False:
+        
+            m = main.get_item("contacts")
+            m.clear()
+            m.add_action(self.modules.contacts.Persons)
+            m.add_action(self.modules.pcsw.Clients,label=string_concat(u' \u25b6 ',self.modules.pcsw.Clients.label))
+            #~ m.add_action(self.modules.pcsw.Clients,'find_by_beid')
+            m.add_action(self.modules.contacts.Companies)
+            m.add_action(self.modules.households.Households)
+            m.add_separator('-')
+            m.add_action(self.modules.contacts.Partners,label=_("Partners (all)"))
         
         m = main.add_menu("reports",_("Listings"))
         self.on_each_app('setup_reports_menu',ui,profile,m)
@@ -172,7 +162,6 @@ class Site(Site,cbss.SiteMixin):
         self.on_each_app('setup_explorer_menu',ui,profile,m)
         m.add_action(self.modules.properties.Properties)
 
-        
         m = main.add_menu("site",_("Site"))
         #~ self.modules.lino.setup_site_menu(self,ui,user,m)
         self.on_each_app('setup_site_menu',ui,profile,m)
@@ -204,6 +193,7 @@ class Site(Site,cbss.SiteMixin):
             
         yield 'lino_welfare.modlib.system'
         yield 'django.contrib.contenttypes'
+        yield 'django.contrib.humanize' # translations for 
         yield 'lino.modlib.users'
         yield 'lino.modlib.changes'
         #~ yield 'lino.modlib.codechanges'
@@ -220,11 +210,15 @@ class Site(Site,cbss.SiteMixin):
         #~ 'lino.modlib.thirds'
         yield 'lino.modlib.outbox'
         yield 'lino_welfare.modlib.cal'
-        yield 'lino.modlib.reception'
-        yield 'lino.modlib.postings'
+        #~ yield 'lino.modlib.postings'
         yield 'lino_welfare.modlib.households'
+        yield 'lino_welfare.modlib.reception'
+        yield 'lino.modlib.languages'
         yield 'lino.modlib.accounts'
         
+        if False: # not yet ready
+            yield 'lino.modlib.families'
+        
         yield 'lino_welfare'
         yield 'lino_welfare.modlib.statbel'
         # NOTE: ordering influences (1) main menu (2) fixtures loading
@@ -232,12 +226,12 @@ class Site(Site,cbss.SiteMixin):
         yield 'lino_welfare.modlib.cv'
         yield 'lino_welfare.modlib.isip'
         yield 'lino_welfare.modlib.jobs'
-        yield 'lino_welfare.modlib.courses'
         yield 'lino_welfare.modlib.integ'
+        yield 'lino_welfare.modlib.courses'
         yield 'lino_welfare.modlib.newcomers'
         yield 'lino_welfare.modlib.debts'
         yield 'lino_welfare.modlib.cbss'
-        yield 'lino.modlib.notes' # notes demo fixture creates notes for Clients 
+        yield 'lino_welfare.modlib.notes' # notes demo fixture creates notes for Clients 
       
     #~ def get_urls(self):
         #~ from django.conf.urls.defaults import patterns
@@ -250,6 +244,13 @@ class Site(Site,cbss.SiteMixin):
             #~ )
         #~ return urlpatterns
         
+    def get_admin_main_items(self,ar):
+        yield self.modules.integ.UsersWithClients
+        yield self.modules.cal.MyEvents
+        yield self.modules.cal.MyTasks
+        yield self.modules.reception.WaitingVisitors
+        yield self.modules.reception.MyWaitingVisitors
+        #~ yield self.modules.reception.ReceivedVisitors
 
 #~ SITE = Site(globals())
 
