@@ -83,6 +83,7 @@ class QuickTests(RemoteAuthTestCase):
         User(username='100',language='de',profile='100').save()
         User(username='110',language='de',profile='110').save()
         User(username='200',language='de',profile='200').save()
+        User(username='210',language='de',profile='210').save()
         User(username='300',language='de',profile='300').save()
         self.user_root = User(username='root',language='en',profile='900') # ,last_name="Superuser")
         self.user_root.save()
@@ -174,7 +175,7 @@ Invalid template '' configured for ContractType 'Art.60\xa77' (expected filename
         self.jobs_contract_1.applies_from=i2d(20130201)
         #~ self.jobs_contract_1.applies_until=i2d(20130228)
         #~ babel.set_language(None)
-        translation.deactivate_all()
+        #~ translation.deactivate_all()
         try:
             self.jobs_contract_1.full_clean()
             self.fail("Expected a ValidationError")
@@ -212,26 +213,27 @@ Invalid template '' configured for ContractType 'Art.60\xa77' (expected filename
         """
         Test whether examination calendar events are being generated,
         """
-        dd.set_language('en')
-        msg = u'Date range overlaps with ISIP #1'
-        self.jobs_contract_1.applies_from = i2d(20120325)
-        self.jobs_contract_1.applies_until = i2d(20130325)
-        try:
-            self.jobs_contract_1.full_clean()
-            self.fail("Expected ValidationError %r" % msg)
-        except ValidationError as e:
-            self.assertEqual(e.messages[0],msg)
+        with translation.override('en'):
+        #~ dd.set_language('en')
+            msg = u'Date range overlaps with ISIP #1'
+            self.jobs_contract_1.applies_from = i2d(20120325)
+            self.jobs_contract_1.applies_until = i2d(20130325)
+            try:
+                self.jobs_contract_1.full_clean()
+                self.fail("Expected ValidationError %r" % msg)
+            except ValidationError as e:
+                self.assertEqual(e.messages[0],msg)
             
-        msg = 'Contract ends before it started.'
-        self.jobs_contract_1.applies_from = i2d(20130325)
-        self.jobs_contract_1.applies_until = i2d(20130131)
-        try:
-            self.jobs_contract_1.full_clean()
-            self.fail("Expected ValidationError %s" % msg)
-        except ValidationError as e:
-            self.assertEqual(e.messages[0],msg)
-        
-        self.jobs_contract_1.save()
+            msg = 'Contract ends before it started.'
+            self.jobs_contract_1.applies_from = i2d(20130325)
+            self.jobs_contract_1.applies_until = i2d(20130131)
+            try:
+                self.jobs_contract_1.full_clean()
+                self.fail("Expected ValidationError %s" % msg)
+            except ValidationError as e:
+                self.assertEqual(e.messages[0],msg)
+            
+            self.jobs_contract_1.save()
       
         
         #~ def test03(self):
@@ -302,8 +304,9 @@ Invalid template '' configured for ContractType 'Art.60\xa77' (expected filename
         p.save()
         
         #~ if 'fr' in settings.SITE.AVAILABLE_LANGUAGES:
-        if settings.SITE.get_language_info('fr'):
-            dd.set_language('fr')
+        with translation.override('fr'):
+        #~ if settings.SITE.get_language_info('fr'):
+            #~ dd.set_language('fr')
             #~ self.assertEqual(p.get_titled_name,"Mr Jean Louis DUPONT")
             self.assertEqual(p.full_name,"M. Jean Louis DUPONT")
             self.assertEqual('\n'.join(p.address_lines()),u"""\
@@ -313,7 +316,7 @@ Bruxelles
 Belgique""")
         
         
-        dd.set_language(None)
+        #~ dd.set_language(None)
             
             
         #~ def test05(self):
@@ -335,7 +338,7 @@ Belgique""")
         a.save()
         self.assertEqual(dd.obj2str(a,True),"Activity(id=1,name='Sozialhilfeempf\\xe4nger')")
         
-        expected = "Client(language='%s'," % settings.SITE.DEFAULT_LANGUAGE.django_code
+        expected = "Client(language='%s'," % settings.SITE.get_default_language()
         expected += "last_name='Test'"
         expected += ",client_state=<ClientStates.newcomer:10>"
         #~ expected += ",is_active=True"
@@ -355,8 +358,7 @@ Belgique""")
         
         """
         from django.db import models
-        from lino.core.fields import get_data_elem
-        de = get_data_elem(pcsw.Client,'id')
+        de = pcsw.Client.get_data_elem('id')
         #~ print de.__class__
         self.assertEqual(de.__class__,models.AutoField)
         self.assertEqual(de.primary_key,True)
@@ -445,7 +447,7 @@ Belgique""")
         modifies the duplicate,
         """
         from lino_welfare.modlib.debts.fixtures.std import objects
-        from north.dbutils import set_language
+        #~ from north.dbutils import set_language
         for obj in objects():
             obj.save()
         self.assertEqual(debts.Budget.objects.count(),0)
@@ -458,17 +460,18 @@ Belgique""")
             e.full_clean()
             e.save()
         ses = settings.SITE.login("root")
-        set_language('de')
-        for e in b1.entry_set.filter(account__ref="3010"):
-            new = ses.run(e.duplicate)
-            #~ e.duplicate()
-        b1.full_clean()
-        b1.save()
-        self.assertEqual(b1.entry_set.count(),45)
-        self.assertEqual(debts.Budget.objects.count(),1)
-        s1 = debts.ResultByBudget.request(b1).to_rst()
-        #~ print s1
-        self.assertEqual(s1,"""\
+        with translation.override('de'):
+        #~ set_language('de')
+            for e in b1.entry_set.filter(account__ref="3010"):
+                new = ses.run(e.duplicate)
+                #~ e.duplicate()
+            b1.full_clean()
+            b1.save()
+            self.assertEqual(b1.entry_set.count(),45)
+            self.assertEqual(debts.Budget.objects.count(),1)
+            s1 = debts.ResultByBudget.request(b1).to_rst()
+            #~ print s1
+            self.assertEqual(s1,"""\
 ========================================================= ===============
  Beschreibung                                              Betrag
 --------------------------------------------------------- ---------------
@@ -478,28 +481,28 @@ Belgique""")
  **Restbetrag für Kredite und Zahlungsrückstände**         **-1 013,67**
 ========================================================= ===============
 """)
-        settings.SITE.site_config.master_budget = b1
-        settings.SITE.site_config.save()
+            settings.SITE.site_config.master_budget = b1
+            settings.SITE.site_config.save()
         
         
-        #~ b2 = b1.duplicate()
-        b2 = ses.run(b1.duplicate)
-        self.assertEqual(debts.Budget.objects.count(),2)
-        #~ b2 = debts.Budget.objects.get(pk=res.get('goto_record_id'))
-        #~ s2 = b2.BudgetSummary().to_rst()
-        s2 = debts.ResultByBudget.request(b2).to_rst()
-        self.assertEqual(s1,s2)
-        for e in b2.entry_set.all():
-            if e.amount:
-                e.amount = e.amount + 2
-                e.full_clean()
-                e.save()
-            
-        s1 = debts.ResultByBudget.request(b1).to_rst()
-        s2 = debts.ResultByBudget.request(b2).to_rst()
-        #~ s1 = b1.BudgetSummary().to_rst()
-        #~ s2 = b2.BudgetSummary().to_rst()
-        self.assertNotEqual(s1,s2)
+            #~ b2 = b1.duplicate()
+            b2 = ses.run(b1.duplicate)
+            self.assertEqual(debts.Budget.objects.count(),2)
+            #~ b2 = debts.Budget.objects.get(pk=res.get('goto_record_id'))
+            #~ s2 = b2.BudgetSummary().to_rst()
+            s2 = debts.ResultByBudget.request(b2).to_rst()
+            self.assertEqual(s1,s2)
+            for e in b2.entry_set.all():
+                if e.amount:
+                    e.amount = e.amount + 2
+                    e.full_clean()
+                    e.save()
+                
+            s1 = debts.ResultByBudget.request(b1).to_rst()
+            s2 = debts.ResultByBudget.request(b2).to_rst()
+            #~ s1 = b1.BudgetSummary().to_rst()
+            #~ s2 = b2.BudgetSummary().to_rst()
+            self.assertNotEqual(s1,s2)
             
             
         cc = courses.CourseContent(name="French")
@@ -595,39 +598,41 @@ Belgique""")
         
         def menu_test(username,expected,debug=False):
             ses = settings.SITE.login(username) 
-            mnu = settings.SITE.get_site_menu(None,ses.get_user().profile)
-            s = mnu.as_rst(ses)
-            if debug:
-                print s
-            self.assertEqual(s.splitlines(),expected.splitlines())
+            with translation.override('de'):
+                mnu = settings.SITE.get_site_menu(None,ses.get_user().profile)
+                s = mnu.as_rst(ses)
+                if debug:
+                    print s
+                self.assertEqual(s.splitlines(),expected.splitlines())
         
         
         menu_test('root',"""\
-- Kontakte : Personen,  ▶ Klienten, Organisationen, Haushalte, -, Partner (alle)
+- Kontakte : Personen,  ▶ Klienten, Organisationen, -, Partner (alle), Haushalte
 
-- Büro :
-  
-  - Mein E-Mail-Ausgang
-  - Postsendungen : Meine Postsendungen, Bereit für Ausdruck, Gedruckte Postsendungen, Ausgegangene Postsendungen
-  - Meine Notizen
+- Büro : Mein E-Mail-Ausgang, Meine Ereignisse/Notizen
 
-- Kalender : Kalender, Termine, -, Meine Aufgaben, To-Do-Liste, -, Meine Anwesenheiten, Meine erhaltenen Einladungen, -, Erwartete Besucher, Wartende Besucher
+- Kalender : Kalender, Meine Termine, Meine Aufgaben, Meine Gäste, Meine Anwesenheiten
 
-- DSBE : Klienten, VSEs, Art.60§7-Konventionen, Stellenanbieter, Stellen, Stellenangebote, Übersicht Art.60§7-Konventionen, Tätigkeitsbericht
+- Empfang : Klienten, Wartende Besucher, Beschäftigte Besucher, Gegangene Besucher, Meine Warteschlange
+
+- DSBE : Klienten, VSEs, Art.60§7-Konventionen, Stellenanbieter, Stellen, Stellenangebote
 
 - Kurse : Kursanbieter, Kursangebote, Offene Kursanfragen
 
-- Neuanträge : Neue Klienten
+- Neuanträge : Neue Klienten, Verfügbare Begleiter
 
 - Schuldnerberatung : Klienten, Meine Budgets
 
-- Listings : Benutzer und ihre Klienten, Datenkontrolle Klienten, Verfügbare Begleiter
+- Listings :
+  
+  - ÖSHZ : Datenkontrolle Klienten
+  - DSBE : Benutzer und ihre Klienten, Übersicht Art.60§7-Konventionen, Tätigkeitsbericht
 
 - Konfigurierung :
   
   - Büro : Meine Einfügetexte, Upload-Arten, Notizarten, Ereignisarten
   - System : Site-Parameter, Benutzer, Teams, Inhaltstypen, Hilfetexte
-  - Kontakte : Länder, Orte, Sprachen, Organisationsarten, Funktionen
+  - Kontakte : Länder, Orte, Organisationsarten, Funktionen, Sprachen
   - Eigenschaften : Eigenschaftsgruppen, Eigenschafts-Datentypen
   - Kalender : Räume, Prioritäten, Gastrollen, Kalenderliste
   - Haushalte : Rollen in Haushalt, Haushaltsarten
@@ -641,19 +646,18 @@ Belgique""")
 
 - Explorer :
   
-  - Büro : Einfügetexte, Uploads, E-Mail-Ausgänge, Anhänge, Postsendungen
-  - System : Vollmachten, User Groups, Benutzer-Levels, Benutzerprofile, Änderungen
+  - Büro : Einfügetexte, Uploads, E-Mail-Ausgänge, Anhänge, Ereignisse/Notizen
+  - System : Vollmachten, Benutzergruppen, Benutzer-Levels, Benutzerprofile, Änderungen
   - Kontakte : Kontaktpersonen
-  - Kalender : Aufgaben, Gäste, Abonnements, Zustände, Zustände, Zustände
+  - Kalender : Aufgaben, Gäste, Abonnements, Termin-Zustände, Gast-Zustände, Aufgaben-Zustände
   - Haushalte : Mitglieder
-  - ÖSHZ : Begleitungen, Klientenkontakte, AG-Sperren, Zivilstände, Bearbeitungszustände Klienten, eID-Kartenarten
+  - ÖSHZ : Begleitungen, Klientenkontakte, AG-Sperren, Klienten, Zivilstände, Bearbeitungszustände Klienten, eID-Kartenarten
   - CV : Sprachkenntnisse
   - DSBE : VSEs, Art.60§7-Konventionen, Stellenanfragen, Ausbildungen und Studien
   - Kurse : Kurse, Kursanfragen
   - Kompetenzen
   - Schuldnerberatung : Budgets, Einträge
   - ZDSS : IdentifyPerson-Anfragen, ManageAccess-Anfragen, Tx25-Anfragen
-  - Ereignisse/Notizen
   - Eigenschaften
 
 - Site : Info
@@ -661,21 +665,21 @@ Belgique""")
         
         # integration agent
         menu_test("100","""\
-- Kontakte : Personen,  ▶ Klienten, Organisationen, Haushalte, -, Partner (alle)
+- Kontakte : Personen,  ▶ Klienten, Organisationen, -, Partner (alle), Haushalte
 
-- Büro :
-  
-  - Mein E-Mail-Ausgang
-  - Postsendungen : Meine Postsendungen, Bereit für Ausdruck, Gedruckte Postsendungen, Ausgegangene Postsendungen
-  - Meine Notizen
+- Büro : Mein E-Mail-Ausgang, Meine Ereignisse/Notizen
 
-- Kalender : Kalender, Termine, -, Meine Aufgaben, To-Do-Liste, -, Meine Anwesenheiten, Meine erhaltenen Einladungen, -, Wartende Besucher
+- Kalender : Kalender, Meine Termine, Meine Aufgaben, Meine Gäste, Meine Anwesenheiten
 
-- DSBE : Klienten, VSEs, Art.60§7-Konventionen, Stellenanbieter, Stellen, Stellenangebote, Übersicht Art.60§7-Konventionen, Tätigkeitsbericht
+- Empfang : Meine Warteschlange
+
+- DSBE : Klienten, VSEs, Art.60§7-Konventionen, Stellenanbieter, Stellen, Stellenangebote
 
 - Kurse : Kursanbieter, Kursangebote, Offene Kursanfragen
 
-- Listings : Benutzer und ihre Klienten
+- Listings :
+  
+  - DSBE : Benutzer und ihre Klienten, Übersicht Art.60§7-Konventionen, Tätigkeitsbericht
 
 - Konfigurierung :
   
@@ -691,21 +695,21 @@ Belgique""")
 
         # 110 integration agent (manager)
         menu_test("110","""\
-- Kontakte : Personen,  ▶ Klienten, Organisationen, Haushalte, -, Partner (alle)
+- Kontakte : Personen,  ▶ Klienten, Organisationen, -, Partner (alle), Haushalte
 
-- Büro :
-  
-  - Mein E-Mail-Ausgang
-  - Postsendungen : Meine Postsendungen, Bereit für Ausdruck, Gedruckte Postsendungen, Ausgegangene Postsendungen
-  - Meine Notizen
+- Büro : Mein E-Mail-Ausgang, Meine Ereignisse/Notizen
 
-- Kalender : Kalender, Termine, -, Meine Aufgaben, To-Do-Liste, -, Meine Anwesenheiten, Meine erhaltenen Einladungen, -, Wartende Besucher
+- Kalender : Kalender, Meine Termine, Meine Aufgaben, Meine Gäste, Meine Anwesenheiten
 
-- DSBE : Klienten, VSEs, Art.60§7-Konventionen, Stellenanbieter, Stellen, Stellenangebote, Übersicht Art.60§7-Konventionen, Tätigkeitsbericht
+- Empfang : Meine Warteschlange
+
+- DSBE : Klienten, VSEs, Art.60§7-Konventionen, Stellenanbieter, Stellen, Stellenangebote
 
 - Kurse : Kursanbieter, Kursangebote, Offene Kursanfragen
 
-- Listings : Benutzer und ihre Klienten
+- Listings :
+  
+  - DSBE : Benutzer und ihre Klienten, Übersicht Art.60§7-Konventionen, Tätigkeitsbericht
 
 - Konfigurierung :
   
@@ -718,7 +722,7 @@ Belgique""")
 
 - Explorer :
   
-  - Büro : E-Mail-Ausgänge, Anhänge, Postsendungen
+  - Büro : E-Mail-Ausgänge, Anhänge
   - Kalender : Aufgaben, Abonnements
   - CV : Sprachkenntnisse
   - DSBE : VSEs, Art.60§7-Konventionen, Stellenanfragen, Ausbildungen und Studien
@@ -729,15 +733,13 @@ Belgique""")
 
         # 300 debts consultant
         menu_test('300',"""\
-- Kontakte : Personen,  ▶ Klienten, Organisationen, Haushalte, -, Partner (alle)
+- Kontakte : Personen,  ▶ Klienten, Organisationen, -, Partner (alle), Haushalte
 
-- Büro :
-  
-  - Mein E-Mail-Ausgang
-  - Postsendungen : Meine Postsendungen, Bereit für Ausdruck, Gedruckte Postsendungen, Ausgegangene Postsendungen
-  - Meine Notizen
+- Büro : Mein E-Mail-Ausgang, Meine Ereignisse/Notizen
 
-- Kalender : Kalender, Termine, -, Meine Aufgaben, To-Do-Liste, -, Meine Anwesenheiten, Meine erhaltenen Einladungen, -, Wartende Besucher
+- Kalender : Kalender, Meine Termine, Meine Aufgaben, Meine Gäste, Meine Anwesenheiten
+
+- Empfang : Meine Warteschlange
 
 - Schuldnerberatung : Klienten, Meine Budgets
 
@@ -752,19 +754,19 @@ Belgique""")
 
         # 200 newcomers
         menu_test('200',"""\
-- Kontakte : Personen,  ▶ Klienten, Organisationen, Haushalte, -, Partner (alle)
+- Kontakte : Personen,  ▶ Klienten, Organisationen, -, Partner (alle), Haushalte
 
-- Büro :
+- Büro : Mein E-Mail-Ausgang, Meine Ereignisse/Notizen
+
+- Kalender : Kalender, Meine Termine, Meine Aufgaben, Meine Gäste, Meine Anwesenheiten
+
+- Empfang : Meine Warteschlange
+
+- Neuanträge : Neue Klienten, Verfügbare Begleiter
+
+- Listings :
   
-  - Mein E-Mail-Ausgang
-  - Postsendungen : Meine Postsendungen, Bereit für Ausdruck, Gedruckte Postsendungen, Ausgegangene Postsendungen
-  - Meine Notizen
-
-- Kalender : Kalender, Termine, -, Meine Aufgaben, To-Do-Liste, -, Meine Anwesenheiten, Meine erhaltenen Einladungen, -, Erwartete Besucher, Wartende Besucher
-
-- Neuanträge : Neue Klienten
-
-- Listings : Benutzer und ihre Klienten, Verfügbare Begleiter
+  - DSBE : Benutzer und ihre Klienten
 
 - Konfigurierung :
   
@@ -775,9 +777,10 @@ Belgique""")
 """) # 200 newcomers
 
 
+        # 210 reception
+        menu_test('210',"""\
+- Empfang : Klienten, Wartende Besucher, Beschäftigte Besucher, Gegangene Besucher
+- Site : Info
+""") # 210 reception
+
 
-        #~ kw = dict(id=1,user=User.objects.get(username='300'))
-        #~ kw.update(partner=)
-        #~ mb = debts.Budget(**kw)
-        #~ mb.save()
-        #~ settings.SITE.site_config.master_budget = mb
