@@ -232,13 +232,13 @@ class WatchTimTests(TestCase):
         s = changes_to_rst(client.partner_ptr)
         #~ print s
         self.assertEqual(s,"""\
-=========== ============== ============================= ============================================================================= ============= ===========
- Benutzer    Änderungsart   Object                        Änderungen                                                                    Object type   object id
------------ -------------- ----------------------------- ----------------------------------------------------------------------------- ------------- -----------
- watch_tim   Erstellen      alicia / Voldemort-Potter H   Coaching(id=1,user=2,client=4260,start_date=1985-07-23,type=2,primary=True)   Begleitung    1
- watch_tim   Add child      Harald VOLDEMORT-POTTER       pcsw.Client                                                                   Person        4260
- watch_tim   Add child      Voldemort-Potter Harald       contacts.Person                                                               Partner       4260
-=========== ============== ============================= ============================================================================= ============= ===========
+=========== ============= ============================= ============================================================================= ============= ===========
+ User        Change Type   Object                        Changes                                                                       Object type   object id
+----------- ------------- ----------------------------- ----------------------------------------------------------------------------- ------------- -----------
+ watch_tim   Create        alicia / Voldemort-Potter H   Coaching(id=1,user=2,client=4260,start_date=1985-07-23,type=2,primary=True)   Coaching      1
+ watch_tim   Add child     Harald VOLDEMORT-POTTER       pcsw.Client                                                                   Person        4260
+ watch_tim   Add child     Voldemort-Potter Harald       contacts.Person                                                               Partner       4260
+=========== ============= ============================= ============================================================================= ============= ===========
 """)
 
         #~ def test05(self):
@@ -338,24 +338,24 @@ class WatchTimTests(TestCase):
         s = changes_to_rst(obj.partner_ptr)
         #~ print s
         self.assertEqual(s,"""\
-+-----------+----------------+---------------------+------------------------------------------------------+--------------+-----------+
-| Benutzer  | Änderungsart   | Object              | Änderungen                                           | Object type  | object id |
-+===========+================+=====================+======================================================+==============+===========+
-| watch_tim | Aktualisierung | Air Liquide Belgium | - activity_id : None --> 19                          | Organisation | 5         |
-|           |                |                     | - city_id : None --> 3                               |              |           |
-|           |                |                     | - bank_account1 : '' --> 'GKCCBEBB:BE57551373330235' |              |           |
-|           |                |                     | - fax : '' --> '04/341.20.70'                        |              |           |
-|           |                |                     | - street_no : '' --> '8'                             |              |           |
-|           |                |                     | - vat_id : '' --> 'BE-0441.857.467'                  |              |           |
-|           |                |                     | - prefix : '' --> 'S.A.'                             |              |           |
-|           |                |                     | - street : '' --> 'Quai des Vennes'                  |              |           |
-|           |                |                     | - remarks : '' --> '\\n'                              |              |           |
-|           |                |                     | - language : 'de' --> 'fr'                           |              |           |
-|           |                |                     | - phone : '' --> '04/349.89.89'                      |              |           |
-|           |                |                     | - country_id : None --> 'B'                          |              |           |
-|           |                |                     | - bank_account2 : '' --> 'BBRUBEBB:BE12310110444892' |              |           |
-|           |                |                     | - zip_code : '' --> '4020'                           |              |           |
-+-----------+----------------+---------------------+------------------------------------------------------+--------------+-----------+
++-----------+-------------+---------------------+------------------------------------------------------+-------------+-----------+
+| User      | Change Type | Object              | Changes                                              | Object type | object id |
++===========+=============+=====================+======================================================+=============+===========+
+| watch_tim | Update      | Air Liquide Belgium | - activity_id : None --> 19                          | Company     | 5         |
+|           |             |                     | - city_id : None --> 3                               |             |           |
+|           |             |                     | - bank_account1 : '' --> 'GKCCBEBB:BE57551373330235' |             |           |
+|           |             |                     | - fax : '' --> '04/341.20.70'                        |             |           |
+|           |             |                     | - street_no : '' --> '8'                             |             |           |
+|           |             |                     | - vat_id : '' --> 'BE-0441.857.467'                  |             |           |
+|           |             |                     | - prefix : '' --> 'S.A.'                             |             |           |
+|           |             |                     | - street : '' --> 'Quai des Vennes'                  |             |           |
+|           |             |                     | - remarks : '' --> '\\n'                              |             |           |
+|           |             |                     | - language : 'de' --> 'fr'                           |             |           |
+|           |             |                     | - phone : '' --> '04/349.89.89'                      |             |           |
+|           |             |                     | - country_id : None --> 'B'                          |             |           |
+|           |             |                     | - bank_account2 : '' --> 'BBRUBEBB:BE12310110444892' |             |           |
+|           |             |                     | - zip_code : '' --> '4020'                           |             |           |
++-----------+-------------+---------------------+------------------------------------------------------+-------------+-----------+
 """)
         
 
@@ -375,7 +375,7 @@ class WatchTimTests(TestCase):
         #~ print s
         self.assertEqual(s,"""\
 =========== ============== =============== ================== ============= ===========
- Benutzer    Änderungsart   Object          Änderungen         Object type   object id
+ User        Change Type    Object          Changes            Object type   object id
 ----------- -------------- --------------- ------------------ ------------- -----------
  watch_tim   Add child      Andenne, CPAS   contacts.Company   Partner       9932
  watch_tim   Remove child                   contacts.Person    Person        9932
@@ -447,14 +447,15 @@ class WatchTimTests(TestCase):
         nicht leer sein. Wenn es das ist, soll watch_tim es auf 01.01.1990
         setzen. 
         """
-        self.assertDoesNotExist(Coaching,client_id=7826)
-        ln = ln.replace('"NB2":""','"NB2":"940702 234-24"')
-        process_line(ln)
-        obj = Client.objects.get(id=7826)
-        self.assertEqual(obj.name,"Mustermann Peter")
-        s = coachings_to_rst(obj)
-        #~ print s
-        self.assertEqual(s,"""\
+        with translation.override('de'):
+            self.assertDoesNotExist(Coaching,client_id=7826)
+            ln = ln.replace('"NB2":""','"NB2":"940702 234-24"')
+            process_line(ln)
+            obj = Client.objects.get(id=7826)
+            self.assertEqual(obj.name,"Mustermann Peter")
+            s = coachings_to_rst(obj)
+            #~ print s
+            self.assertEqual(s,"""\
 ====================== ===== =========== ======== ======== ================== =======
  Begleitet seit         bis   Begleiter   Primär   Dienst   Beendigungsgrund   ID
 ---------------------- ----- ----------- -------- -------- ------------------ -------
@@ -462,11 +463,11 @@ class WatchTimTests(TestCase):
  **Total (1 Zeilen)**                     **1**                                **0**
 ====================== ===== =========== ======== ======== ================== =======
 """)
-        ln = ln.replace('"IDPRT":"S"','"IDPRT":"I"')
-        process_line(ln)
-        s = coachings_to_rst(obj)
-        #~ print s
-        self.assertEqual(s,"""\
+            ln = ln.replace('"IDPRT":"S"','"IDPRT":"I"')
+            process_line(ln)
+            s = coachings_to_rst(obj)
+            #~ print s
+            self.assertEqual(s,"""\
 ====================== ========== =========== ======== ======== ================== =======
  Begleitet seit         bis        Begleiter   Primär   Dienst   Beendigungsgrund   ID
 ---------------------- ---------- ----------- -------- -------- ------------------ -------
@@ -519,7 +520,30 @@ class WatchTimTests(TestCase):
         process_line(ln)
         self.assertDoesNotExist(Company,id=4124)
         obj = Household.objects.get(id=4124)
+        
+        
+        ln = """{"method":"PUT","alias":"PAR","id":"0000001315",
+        "time":"20130811 10:33:20","user":"PAC","data":{"IDPAR":"0000001315",
+        "FIRME":"C2D System House","NAME2":"",
+        "RUE":"Rue des Champs","CP":"4630","IDPRT":"V","PAYS":"B","TEL":"04/567.89.10",
+        "FAX":"04/365.31.10","COMPTE1":"JVBABE22:BE39645678910619",
+        "NOTVA":"BE-0123.456.789","COMPTE3":"","IDPGP":"",
+        "DEBIT":"","CREDIT":"","ATTRIB":"","IDMFC":"30","LANGUE":"F",
+        "IDBUD":"","PROF":"22","CODE1":"","CODE2":"","CODE3":"",
+        "DATCREA":{"__date__":{"year":1992,"month":7,"day":24}},"ALLO":"S.A.",
+        "NB1":"EUPO","NB2":"","IDDEV":"","MEMO":"","COMPTE2":"",
+        "RUENUM":"   8","RUEBTE":"","DEBIT2":"","CREDIT2":"",
+        "IMPDATE":{"__date__":{"year":2012,"month":10,"day":25}},
+        "ATTRIB2":"","CPTSYSI":"","EMAIL":"info@c2d.be",
+        "MVIDATE":{"__date__":{"year":2012,"month":1,"day":25}},
+        "IDUSR":"","DOMI1":""}} """
 
+        self.assertDoesNotExist(Partner,id=1315)
+        process_line(ln)
+        obj = Partner.objects.get(id=1315)
+        obj = Company.objects.get(id=1315)
+        for m in Person, Client, Household:
+            self.assertDoesNotExist(m,id=1315)
 
 
 
